Cryptographic Module Validation Program | CSRC
Author: Computer Security Division, Information Technology Laboratory, National Institute of Standards and Technology, U.S. Department of Commerce
Description: The IUT list is provided as a marketing service for vendors who have a viable contract with an accredited laboratory for the testing of a cryptographic module. The CMVP does not have detailed information about the specific cryptographic module or when the...
Date: 2016-10-11

You are viewing this page in an unauthorized frame window.

This is a potential security issue, you are being redirected to https://csrc.nist.gov.

An official website of the United States government

Official websites use .gov
A .gov website belongs to an official government organization in the United States.

Secure .gov websites use HTTPS
A lock () or https:// means you've safely connected to the .gov website. Share sensitive information only on official, secure websites.

# Cryptographic Module Validation Program CMVP

### Implementation Under Test List

The IUT list is provided as a marketing service for vendors who have a viable contract with an accredited laboratory for the testing of a cryptographic module. The CMVP does not have detailed information about the specific cryptographic module or when the test report will be submitted to the CMVP for validation. When the lab submits the test report to the CMVP, the module will transition from the IUT list to the MIP list. If you would like more information about a specific cryptographic module or its schedule, please contact the vendor.

Last Updated: 12/9/2021

Module Name | Vendor Name | Standard | IUT Date
--- | --- | --- | ---
3e-520 Secure Access Point Cryptographic Module | 3e Technologies International, Inc. | FIPS 140-2 | 7/2/2021
3e-636M-HSE CyberFence Cryptographic Module | 3e Technologies International, Inc. | FIPS 140-2 | 7/2/2021
ADVA CRYPTOMUX (MA-2C2C3LT-A) and CRYPTOMUX+ (MA-B2C3LT-A) encryption modules | ADVA Optical Networking SE | FIPS 140-2 | 7/16/2020
Infraguard Processor Module (I.P.M.) | Advantor Systems L.L.C. | FIPS 140-2 | 12/18/2020
AWS Cryptographic Module | Amazon Web Services Inc. | FIPS 140-3 | 6/3/2021
TuffServ® Encryption Module | Ampex Data Systems Corporation | FIPS 140-3 | 3/1/2021
APACER SSD Drive SV240 | Apacer Technology Inc. | FIPS 140-2 | 6/15/2020
Apple corecrypto Module v11.1 [Apple silicon, Secure Key Store, Hardware, SL2/PHY3] | Apple Inc. | FIPS 140-3 | 6/2/2021
Apple corecrypto Module v11.1 [Apple silicon, Secure Key Store, Hardware] | Apple Inc. | FIPS 140-3 | 9/21/2020
Apple corecrypto Module v12.0 [Intel, Kernel, Software, SL1] | Apple Inc. | FIPS 140-3 | 4/5/2021
Apple corecrypto Module v12.0 [Intel, User, Software, SL1] | Apple Inc. | FIPS 140-3 | 4/5/2021
Arista CloudEOS Router Module | Arista Networks, Inc. | FIPS 140-3 | 10/20/2021
Arista CloudVision Portal Module | Arista Networks, Inc. | FIPS 140-3 | 10/20/2021
Arista MACsec Charlie Hybrid Module | Arista Networks, Inc. | FIPS 140-3 | 12/30/2020
Aruba AOS-CX Cryptographic Module | Aruba, a Hewlett Packard Enterprise company | FIPS 140-2 | 12/11/2020
Aruba Common Crypto Module | Aruba, a Hewlett Packard Enterprise company | FIPS 140-2 | 3/10/2021
Aruba IAP-315, IAP-345, IAP-377, IAP-503R, IAP-505H, IAP-504, IAP-505, IAP-514, IAP-515, IAP-534, IAP-535, and IAP-555 Access Points with Aruba Instant Firmware | Aruba, a Hewlett Packard Enterprise company | FIPS 140-2 | 4/19/2021
Avaya G430 | Avaya Inc. | FIPS 140-2 | 11/23/2020
Avaya G450 | Avaya Inc. | FIPS 140-2 | 11/23/2020
Brocade Fabric OS FIPS Cryptographic Module | Brocade Communications Systems LLC | FIPS 140-3 | 4/7/2021
PTP 820C, PTP 820C-HP, PTP 820S, PTP 820G, PTP 820N, PTP 820A, PTP 850E, PTP 850C, PTP 850S | Cambium Networks | FIPS 140-3 | 1/27/2021
PTP 700 Point to Point Wireless Ethernet Bridge | Cambium Networks, Ltd. | FIPS 140-3 | 10/22/2021
FibeAir® IP-20C, FibeAir® IP-20C-HP, FibeAir® IP-20S, FibeAir® IP-20G, FibeAir® IP-20N, FibeAir® IP-20A, FibeAir® IP-50E, FibeAir® IP-50C, FibeAir® IP-50S | Ceragon Networks | FIPS 140-3 | 1/28/2021
3926-MACSEC | Ciena Corporation | FIPS 140-2 | 5/4/2021
Ciena WaveLogic 5 Extreme Modem | Ciena Corporation | FIPS 140-3 | 4/30/2021
Ciena Waveserver 5 CP Module | Ciena Corporation | FIPS 140-3 | 4/30/2021
Cisco Linux Kernel FIPS Object Module (KFOM) Cryptographic Module | Cisco System, Inc | FIPS 140-3 | 6/7/2021
Cisco Catalyst 9800 (40/80) Wireless Controllers | Cisco Systems, Inc | FIPS 140-2 | 12/4/2020
Cisco Catalyst 9800-CL Wireless Controller | Cisco Systems, Inc | FIPS 140-2 | 12/4/2020
Cisco Catalyst Embedded Wireless Controllers | Cisco Systems, Inc | FIPS 140-2 | 12/21/2020
Cisco Adaptive Security Appliance (ASA) | Cisco Systems, Inc. | FIPS 140-3 | 3/12/2021
Cisco Adaptive Security Appliance Virtual (ASAv) | Cisco Systems, Inc. | FIPS 140-3 | 3/12/2021
Cisco ASA Cryptographic Module on 4K/9K | Cisco Systems, Inc. | FIPS 140-3 | 3/12/2021
Cisco ASA FX-OS Cryptographic Module | Cisco Systems, Inc. | FIPS 140-3 | 3/3/2021
Cisco ASR 9000 Aggregated Services Routers | Cisco Systems, Inc. | FIPS 140-2 | 8/17/2020
Cisco Catalyst 8300 Series Edge Platforms | Cisco Systems, Inc. | FIPS 140-2 | 1/14/2021
Cisco Catalyst 8500 Series Edge Platforms | Cisco Systems, Inc. | FIPS 140-2 | 1/14/2021
Cisco FIPS Object Module | Cisco Systems, Inc. | FIPS 140-3 | 8/31/2021
Cisco Firepower Management Center (FMC) Virtual | Cisco Systems, Inc. | FIPS 140-3 | 3/12/2021
Cisco Firepower Next-Generation IPS Virtual (NGIPSv) | Cisco Systems, Inc. | FIPS 140-3 | 3/12/2021
Cisco Firepower Threat Defense (FTD) and FX-OS on the FPR 1K and FPR 2K Appliance | Cisco Systems, Inc. | FIPS 140-3 | 3/5/2021
Cisco Firepower Threat Defense (FTD) on ASA/ISA Cryptographic Module | Cisco Systems, Inc. | FIPS 140-3 | 5/24/2021
Cisco Firepower Threat Defense (FTD) Virtual | Cisco Systems, Inc. | FIPS 140-3 | 3/12/2021
Cisco Firepower Threat Defense on 4K/9K Cryptographic Module | Cisco Systems, Inc. | FIPS 140-3 | 3/12/2021
Cisco FX-OS Cryptographic Module on 4K/9K | Cisco Systems, Inc. | FIPS 140-3 | 3/12/2021
Cisco FX-OS on 4K/9K Cryptographic Module | Cisco Systems, Inc. | FIPS 140-3 | 3/12/2021
Cloudpath Enrollment Server (ES) | CommScope Technologies LLC | FIPS 140-2 | 7/6/2021
Port Authority Series | Communication Devices, Inc. | FIPS 140-3 | 3/19/2021
Compunetix Evergreen MCU | Compunetix, Inc. | FIPS 140-2 | 12/14/2020
Cryptographic Module | Comtech EF Data Corporation | FIPS 140-2 | 12/10/2020
Comtech Systems Corporation CS67PLUS Cryptographic Module (CCM) | Comtech Systems, Inc. | FIPS 140-2 | 7/30/2020
CorSSL™ | Corsec Security, Inc. | FIPS 140-3 | 8/7/2021
cVu 16100 Network Packet Broker | cPacket Networks, Inc. | FIPS 140-2 | 6/16/2021
Cradlepoint Cryptographic Module | Cradlepoint, Inc. | FIPS 140-3 | 10/20/2021
Cradlepoint Kernel Cryptographic Module | Cradlepoint, Inc. | FIPS 140-3 | 12/1/2021
Cyphre Crypto Core | Cyphre Security Solutions LLC (A Rignet Company) | FIPS 140-3 | 10/29/2020
Dell BSAFE Crypto Module for C, v3.0 | Dell Inc., BSAFE Product Team | FIPS 140-3 | 9/17/2021
Dell BSAFE Crypto Module 2.0 | Dell Inc., BSAFE Product Team | FIPS 140-3 | 11/16/2020
Dell BSAFE Crypto Module for Java, v7.0 | Dell Inc., BSAFE Product Team | FIPS 140-3 | 9/22/2021
Dell Crypto Library for Dell iDRAC, Dell CMC and DellOME-M | Dell, Inc. | FIPS 140-2 | 9/22/2021
DocuSign HSM Appliance | DocuSign, Inc. | FIPS 140-2 | 9/22/2021
DocuSign QSCD Appliance | DocuSign, Inc. | FIPS 140-2 | 9/4/2020
DocuSign Signature Appliance | DocuSign, Inc. | FIPS 140-2 | 9/22/2021
Dynatrace Cryptographic Module | Dynatrace LLC | FIPS 140-3 | 8/27/2021
Kenwood Cryptographic Library (KCL) | EF Johnson Technologies | FIPS 140-3 | 5/19/2021
nShield 5s F3 & nShield 5s for nShield 5c and for nShield HSMi | Entrust | FIPS 140-3 | 10/20/2021
ExtraHop Cryptographic Module | ExtraHop Networks | FIPS 140-3 | 8/19/2021
Annapurna NVMe SSD | FADU, Inc. | FIPS 140-2 | 11/4/2020
Forcepoint Next Generation Firewall | Forcepoint | FIPS 140-3 | 6/22/2021
Forcepoint NGFW Cryptographic Kernel Module | Forcepoint | FIPS 140-3 | 6/22/2021
Fornetix VaultCore | Fornetix LLC | FIPS 140-2 | 5/11/2021
Fortanix Data Security Manager | Fortanix, Inc. | FIPS 140-2 | 5/27/2021
FortiClient 7.0 for Windows | Fortinet, Inc. | FIPS 140-2 | 9/10/2020
FortiGate 6000 Series with FortiOS 6.4 | Fortinet, Inc. | FIPS 140-2 | 6/16/2021
FortiGate Appliances with FortiOS 6.4 & 7.0 | Fortinet, Inc. | FIPS 140-2 | 3/29/2021
FortiGate-VM v6.4 & v7.0 | Fortinet, Inc. | FIPS 140-2 | 3/29/2021
FortiOS 6.4 & 7.0 | Fortinet, Inc. | FIPS 140-2 | 3/29/2021
FortiSwitch E series with OS v7.0 | Fortinet, Inc. | FIPS 140-2 | 6/16/2021
FunOS Crypto Module | Fungible Inc. | FIPS 140-2 | 3/22/2021
Secure Enclave | Fungible Inc. | FIPS 140-2 | 3/22/2021
Raven Cryptographic Module | Google LLC. | FIPS 140-3 | 2/10/2021
Android Kernel Cryptographic Module | Google, LLC | FIPS 140-2 | 10/28/2020
Cr50 U2F | Google, LLC | FIPS 140-2 | 5/20/2021
Google Tensor UFS Inline Storage Encryption | Google, LLC | FIPS 140-2 | 9/14/2021
iLO 5 Cryptographic Module | Hewlett Packard Enterprise Development LP | FIPS 140-2 | 10/28/2020
Hughes HT2010 Satellite Terminal | Hughes Network Systems, LLC | FIPS 140-2 | 8/17/2020
Hughes HT2300, HT2500, HT2550, HT2650 Satellite Terminals | Hughes Network Systems, LLC | FIPS 140-2 | 8/17/2020
Hypersecu ServSec HSM Cryptographic Module | Hypersecu Information Systems Inc | FIPS 140-2 | 9/8/2021
IBM 4769-001 Enterprise PKCS#11 HSM | IBM | FIPS 140-2 | 8/2/2021
IBM 4770-001 Cryptographic Coprocessor Security Module | IBM | FIPS 140-3 | 12/3/2021
IBM 4770-001 Enterprise PKCS#11 HSM | IBM | FIPS 140-2 | 8/2/2021
IBM Cloud Object Storage System’s ™ FIPS Cryptographic Module | IBM | FIPS 140-2 | 6/25/2021
Qradar SIEM Core | IBM | FIPS 140-2 | 4/5/2021
IBM® NVMe FlashCore™ Module 2 | IBM® Corporation | FIPS 140-3 | 6/22/2021
UT-125 FIPS #31 and UT-125 FIPS #41 Cryptographic Modules | Icom Inc. | FIPS 140-3 | 11/24/2020
TRANSEC Module | iDirect Government, LLC | FIPS 140-2 | 6/29/2021
SEMPER Secure NOR Flash (S35HS256T, S35HL256T) | Infineon Technologies LLC - Memory Solutions | FIPS 140-3 | 11/15/2021
Infoblox Trinzic DDI Appliances TE-815, TE-825, TR-805, ND-805, TE-1415, TE-1425, TR-1405, ND-1405, TE-2215, TE-2225, TR-2205, ND-2205, TE-4015, TE-4025, TR-4005, ND-4005 | Infoblox | FIPS 140-2 | 10/13/2020
Infoblox Trinzic Virtual DDI appliance | Infoblox | FIPS 140-2 | 10/13/2020
Intel® Optane™ Persistent Memory 300 Series | Intel Corporation | FIPS 140-3 | 10/26/2021
Intel® Optane™ SSD DC D5800X | Intel Corporation | FIPS 140-3 | 9/26/2020
Intel® SSD DC P5316 | Intel Corporation | FIPS 140-3 | 3/25/2021
Intel® SSD DC P5520 | Intel Corporation | FIPS 140-3 | 3/25/2021
Juniper Networks MX10003 3D Universal Edge Router with MACSec MIC and EX9253 Ethernet Switch with MACSec Line Card | Juniper Networks, Inc. | FIPS 140-2 | 6/22/2021
Juniper Networks MX240, MX480 and MX960 series with Macsec card MPC10E-10C and MPC10E-15C | Juniper Networks, Inc. | FIPS 140-2 | 11/9/2020
Juniper Networks SRX1500, SRX4100, SRX4200, SRX4600, SRX5400, SRX5600 and SRX5800 Services Gateway | Juniper Networks, Inc. | FIPS 140-2 | 5/28/2021
Juniper Networks vSRX 3.0 Virtual Firewall | Juniper Networks, Inc. | FIPS 140-2 | 4/28/2021
MX10003 3D Universal Edge Router with JNP-MIC1-MACSEC MIC | Juniper Networks, Inc. | FIPS 140-2 | 10/5/2021
MX2010 ,MX2020 with REMX2K-X8-64G , RE-S-1800 Routing Engines, MPC9E with MIC-MACSEC-MRATE | Juniper Networks, Inc. | FIPS 140-2 | 10/5/2021
MX240, MX480, MX960 3D Universal Edge Routers with RE-S-X6-64G and RE1800 Routing Engines with macsec capable MPC MPC7E-10GE | Juniper Networks, Inc. | FIPS 140-2 | 10/5/2021
NFX150, NFX250, NFX350 Series JUNOS 21.4R1 FIPS | Juniper Networks, Inc. | FIPS 140-2 | 10/5/2021
PTX1000 Packet Transport Router | Juniper Networks, Inc. | FIPS 140-2 | 10/5/2021
PTX10008 and PTX10016 packet transport routers with routing Engine JNP10K-RE0 and Macsec linecard LC1105-M | Juniper Networks, Inc. | FIPS 140-2 | 10/5/2021
KIOXIA TCG OPAL SSC Self-Encrypting Solid State Drive XD6 Series | KIOXIA Corporation | FIPS 140-3 | 2/26/2021
BC-FJA (Bouncy Castle FIPS Java API) | Legion of the Bouncy Castle Inc. | FIPS 140-3 | 3/2/2021
LogRhythm 7.6 Data Indexer (Linux) | LogRhythm | FIPS 140-2 | 10/21/2020
McAfee OpenSSL FIPS Object Module | McAfee LLC | FIPS 140-2 | 6/4/2021
Boot Manager (Windows 10 version 21H1, Windows Server 2022, et al.) | Microsoft Corporation | FIPS 140-2 | 6/10/2021
Cryptographic Primitives Library (Windows 10 and Windows Server version 20H2) | Microsoft Corporation | FIPS 140-2 | 6/10/2021
Cryptographic Primitives Library (Windows 10 version 21H1, Windows Server 2022, et al.) | Microsoft Corporation | FIPS 140-2 | 6/10/2021
Cryptographic Primitives Library (Windows Server 2019 Standard, Windows Server 2019 Datacenter) | Microsoft Corporation | FIPS 140-2 | 6/10/2021
Kernel Mode Cryptographic Primitives Library (Windows 10 and Windows Server version 20H2) | Microsoft Corporation | FIPS 140-2 | 6/10/2021
Kernel Mode Cryptographic Primitives Library (Windows 10 version 21H1, Windows Server 2022, et al.) | Microsoft Corporation | FIPS 140-2 | 6/10/2021
Kernel Mode Cryptographic Primitives Library (Windows Server 2019 Standard, Windows Server 2019 Datacenter) | Microsoft Corporation | FIPS 140-2 | 6/10/2021
Motorola Solutions Cryptographic Firmware Module | Motorola Solutions, Inc. | FIPS 140-3 | 10/25/2021
NetApp Cryptographic Security Module | NetApp, Inc | FIPS 140-2 | 8/24/2021
NextFlex AirGuardian | NextFlex | FIPS 140-2 | 10/28/2021
Digipass GO7 | OneSpan, Inc. | FIPS 140-2 | 6/30/2021
Acme Packet 1100, Acme Packet 3900, Acme Packet 3950, and Acme Packet 4900 (v9.0) | Oracle Communications | FIPS 140-2 | 4/15/2021
Acme Packet 4600 and Acme Packet 6350 (v9.0) | Oracle Communications | FIPS 140-2 | 4/15/2021
Acme Packet VME (v9.0) | Oracle Communications | FIPS 140-2 | 4/15/2021
Oracle Linux 7 GnuTLS Cryptographic Module | Oracle Corporation | FIPS 140-2 | 9/24/2020
Oracle Linux 7 libgcrypt Cryptographic Module | Oracle Corporation | FIPS 140-2 | 9/24/2020
Oracle OpenSSL FIPS Provider | Oracle Corporation | FIPS 140-2 | 10/7/2021
Tablo Medical Informatics System | Outset Medical, Inc. | FIPS 140-3 | 11/5/2021
Panorama 10.1 running on M-200, M-500 and M-600 | Palo Alto Networks, Inc. | FIPS 140-3 | 6/10/2021
Panorama 10.1 Virtual Appliances | Palo Alto Networks, Inc. | FIPS 140-3 | 6/10/2021
PAN-OS 10.1 running on PA-220, PA-220R, PA-400 Series, PA-800 Series, PA-3200 Series, PA-5200 Series, PA-5450 and PA-7000 Series NGFWs | Palo Alto Networks, Inc. | FIPS 140-3 | 6/10/2021
PAN-OS 10.1 VM-Series | Palo Alto Networks, Inc. | FIPS 140-3 | 6/10/2021
WildFire 10.1 running on WF-500 | Palo Alto Networks, Inc. | FIPS 140-3 | 6/10/2021
Pensando TLS Library | Pensando Systems, Inc | FIPS 140-2 | 10/23/2020
Privoro SafeCase Cryptographic Module | Privoro LLC | FIPS 140-3 | 2/12/2021
FlashBlade Data Encryption Module | Pure Storage, Inc. | FIPS 140-3 | 12/3/2020
Rambus CryptoManager Root of Trust RT-660 | Rambus Inc. | FIPS 140-3 | 7/11/2021
Rambus Root of Trust RT-130 | Rambus Inc. | FIPS 140-3 | 7/11/2021
SafeZone FIPS Cryptographic Module 2.0 | Rambus, Inc. | FIPS 140-3 | 4/5/2021
SBC Software Edition Session Border Controller v9.2 | Ribbon Communications, Inc. | FIPS 140-3 | 9/7/2021
Riverbed Cryptographic module (VN) for Branch | Riverbed Technology, Inc. | FIPS 140-2 | 9/27/2020
Riverbed Cryptographic module (VN) for Controller | Riverbed Technology, Inc. | FIPS 140-2 | 9/27/2020
CryptoComply | SafeLogic | FIPS 140-3 | 4/2/2021
Samsung NVMe TCG Opal SSC SEDs BM1733a Series | Samsung Electronics Co., Ltd. | FIPS 140-3 | 4/8/2021
Seagate Secure™ TCG Enterprise SSC Self-Encrypting HDD | Seagate Technology, LLC | FIPS 140-3 | 1/11/2021
Seagate Secure™ TCG Opal SSC Self-Encrypting HDD | Seagate Technology, LLC | FIPS 140-3 | 1/11/2021
Sepior TSM | Sepior ApS | FIPS 140-3 | 10/29/2020
Silver Peak EdgeConnect EC-XS-FIPS, EC-XL-P-FIPS, and EC-XL-P-NM-FIPS 2021 | Silver Peak Systems Inc. | FIPS 140-2 | 6/22/2021
SonicWall Network Security Manager Appliance | SonicWall, Inc. | FIPS 140-2 | 9/9/2021
SPYRUS USB-3 Module | SPYRUS, Inc. | FIPS 140-2 | 6/17/2021
Symantec Management CenterVirtual Appliance | Symantec & CA Technologies, a division of Broadcom | FIPS 140-2 | 7/14/2021
Tera2 PCoIP Zero Client Processors | Teradici Corporation | FIPS 140-2 | 8/31/2021
Luna G7 Cryptographic Module | Thales | FIPS 140-3 | 2/23/2021
Thales CipherTrust Application Data Protection CryptoAPI (CADP CryptoAPI) Module | Thales | FIPS 140-2 | 2/22/2021
Advanced Configurable Cryptographic Environment (ACCE) v3 HSM Crypto Module | Ultra, Intelligence & Communications | FIPS 140-2 | 8/16/2021
Advanced Configurable Cryptographic Environment (ACCE) v3 HSM Crypto Module | Ultra, Intelligence & Communications | FIPS 140-2 | 5/19/2021
Unbound Multi-Party Cryptographic Module | Unbound Security Inc. | FIPS 140-3 | 12/15/2020
Unbound Multi-Party Cryptographic Module | Unbound Security Inc. | FIPS 140-3 | 12/15/2020
Vehicle Data Device | Verizon Connect | FIPS 140-2 | 2/2/2021
VMware's VMkernel Cryptographic Module | VMware, Inc. | FIPS 140-2 | 11/20/2020
Firebox M290, M390, M590, M690, M4800, M5800 | WatchGuard Technologies, Inc. | FIPS 140-3 | 8/5/2021
Firebox T20, T20-W, T40, T40-W, T40-CW, T80 | WatchGuard Technologies, Inc. | FIPS 140-3 | 8/5/2021
Ultrastar® DC HC550 - Western Digital® | Western Digital Corporation | FIPS 140-2 | 6/12/2020
wolfCrypt | wolfSSL Inc. | FIPS 140-3 | 10/30/2020
Zetetic Cryptographic Module | Zetetic, LLC | FIPS 140-3 | 7/28/2021
XCrypt Full Disk | Zettaset, Inc. | FIPS 140-2 | 8/13/2020
Displayed | 173
Not Displayed | 2
Total | 175

#### Contacts

Beverly Trapnell - NIST CMVP Program Manager
cmvp@nist.gov

Carolyn French - CCCS CMVP Program Manager
CMVP@cyber.gc.ca

#### Group

Security Testing, Validation and Measurement

#### Topics

Security and Privacy: cryptography, testing & validation

Technologies: hardware, software & firmware

#### Related Projects

Automated Cryptographic Validation Testing
Cryptographic Algorithm Validation Program
Deep learning neural networks for CMVP report validation
FIPS 140-3 Transition Effort
Multi-Party Threshold Cryptography
Random Bit Generation
Testing Laboratories

#### Group

Security Testing, Validation and Measurement

#### Topics

Security and Privacy: cryptography, testing & validation

Technologies: hardware, software & firmware

#### Related Projects

Automated Cryptographic Validation Testing
Cryptographic Algorithm Validation Program
Deep learning neural networks for CMVP report validation
FIPS 140-3 Transition Effort
Multi-Party Threshold Cryptography
Random Bit Generation
Testing Laboratories

Created October 11, 2016, Updated December 06, 2021